@@ -1,27 +1,35 @@
-"""Core schema module.
+"""Schema module core (`yvzi`).
 
 Import the package::
 
    import lndb_schema_core
 
-This is the complete API reference:
+All models:
 
 .. autosummary::
    :toctree: .
 
+   user
    dobject
    dtransform
    dtransform_in
    dtransform_out
    jupynb
-   lndb_schema_core
-   track_do
-   track_do_type
-   user
+   usage
+   version_yvzi
+
+Helpers:
+
+.. autosummary::
+   :toctree: .
+
+   usage_type
+   id
 
 """
-
-__version__ = "0.2.1"  # denote a pre-release for 0.1.0 with 0.1a1
+# This is lndb-schema-module yvzi.
+_schema_module_id = "yvzi"
+__version__ = "0.3.0"  # denote a pre-release for 0.1.0 with 0.1a1
 
 from . import id
 from ._core import (  # noqa
@@ -30,8 +38,8 @@ from ._core import (  # noqa
     dtransform_in,
     dtransform_out,
     jupynb,
-    lndb_schema_core,
-    track_do,
-    track_do_type,
+    usage,
+    usage_type,
     user,
+    version_yvzi,
 )
